summaryrefslogtreecommitdiffstats
path: root/ksayit/src/contextmenuhandler.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksayit/src/contextmenuhandler.h')
-rw-r--r--ksayit/src/contextmenuhandler.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/ksayit/src/contextmenuhandler.h b/ksayit/src/contextmenuhandler.h
index 88d7c0e..8bb9d0a 100644
--- a/ksayit/src/contextmenuhandler.h
+++ b/ksayit/src/contextmenuhandler.h
@@ -69,7 +69,7 @@ class ContextMenuHandler : public TQObject
Q_OBJECT
TQ_OBJECT
public:
- ContextMenuHandler(TQObject *tqparent = 0, const char *name = 0);
+ ContextMenuHandler(TQObject *parent = 0, const char *name = 0);
~ContextMenuHandler();
@@ -80,10 +80,10 @@ public:
KPopupMenu* getPopupMenu(ListViewInterface *item);
/**
* \returns A pointer to the Submenu as a child of the tqparent
* \p tqparent.
*/
- KPopupMenu* SubMenuFactory(KPopupMenu *tqparent);
+ KPopupMenu* SubMenuFactory(KPopupMenu *parent);
/**
* Creates an action sufficiant to the given name.
@@ -80,10 +80,10 @@ public:
KPopupMenu* getPopupMenu(ListViewInterface *item);
/**
- * \returns A pointer to the Submenu as a child of the tqparent
- * \p tqparent.
+ * \returns A pointer to the Submenu as a child of the parent
+ * \p parent.
*/